import codebuild = require('@aws-cdk/aws-codebuild');
import codepipeline = require('@aws-cdk/aws-codepipeline');
import cdk = require('@aws-cdk/core');
import { Action } from '../action';
/**
 * The type of the CodeBuild action that determines its CodePipeline Category -
 * Build, or Test.
 * The default is Build.
 */
export declare enum CodeBuildActionType {
    /**
     * The action will have the Build Category.
     * This is the default.
     */
    BUILD = 0,
    /**
     * The action will have the Test Category.
     */
    TEST = 1
}
/**
 * Construction properties of the {@link CodeBuildAction CodeBuild build CodePipeline action}.
 */
export interface CodeBuildActionProps extends codepipeline.CommonAwsActionProps {
    /**
     * The source to use as input for this action.
     */
    readonly input: codepipeline.Artifact;
    /**
     * The list of additional input Artifacts for this action.
     */
    readonly extraInputs?: codepipeline.Artifact[];
    /**
     * The list of output Artifacts for this action.
     * **Note**: if you specify more than one output Artifact here,
     * you cannot use the primary 'artifacts' section of the buildspec;
     * you have to use the 'secondary-artifacts' section instead.
     * See https://docs.aws.amazon.com/codebuild/latest/userguide/sample-multi-in-out.html
     * for details.
     *
     * @default the action will not have any outputs
     */
    readonly outputs?: codepipeline.Artifact[];
    /**
     * The action's Project.
     */
    readonly project: codebuild.IProject;
    /**
     * The type of the action that determines its CodePipeline Category -
     * Build, or Test.
     *
     * @default CodeBuildActionType.BUILD
     */
    readonly type?: CodeBuildActionType;
}
/**
 * CodePipeline build action that uses AWS CodeBuild.
 */
export declare class CodeBuildAction extends Action {
    private readonly props;
    constructor(props: CodeBuildActionProps);
    protected bound(_scope: cdk.Construct, _stage: codepipeline.IStage, options: codepipeline.ActionBindOptions): codepipeline.ActionConfig;
}
