import codepipeline = require('@aws-cdk/aws-codepipeline');
import ecr = require('@aws-cdk/aws-ecr');
import { Construct } from '@aws-cdk/core';
import { Action } from '../action';
/**
 * Construction properties of {@link EcrSourceAction}.
 */
export interface EcrSourceActionProps extends codepipeline.CommonAwsActionProps {
    /**
     * The image tag that will be checked for changes.
     *
     * @default 'latest'
     */
    readonly imageTag?: string;
    /**
     *
     */
    readonly output: codepipeline.Artifact;
    /**
     * The repository that will be watched for changes.
     */
    readonly repository: ecr.IRepository;
}
/**
 * The ECR Repository source CodePipeline Action.
 *
 * Will trigger the pipeline as soon as the target tag in the repository
 * changes, but only if there is a CloudTrail Trail in the account that
 * captures the ECR event.
 */
export declare class EcrSourceAction extends Action {
    private readonly props;
    constructor(props: EcrSourceActionProps);
    protected bound(_scope: Construct, stage: codepipeline.IStage, options: codepipeline.ActionBindOptions): codepipeline.ActionConfig;
}
